pub struct PresentationEngine { /* private fields */ }Expand description
The presentation engine — processes commands and owns the authoritative state.
Called once per frame via tick(). All state mutations happen here.
The UI reads state via a shared Arc<RwLock<PresentationState>>.
Implementations
Sourceimpl PresentationEngine
impl PresentationEngine
Sourcepub fn new(
total_pages: usize,
metadata: &PresentationMetadata,
config: &Config,
receiver: CommandReceiver,
pdf_path: PathBuf,
) -> (Self, Arc<RwLock<PresentationState>>)
pub fn new( total_pages: usize, metadata: &PresentationMetadata, config: &Config, receiver: CommandReceiver, pdf_path: PathBuf, ) -> (Self, Arc<RwLock<PresentationState>>)
Create a new engine from document metadata and config.
Returns the engine and a shared state handle for UI windows.
Sourcepub fn tick(&mut self) -> bool
pub fn tick(&mut self) -> bool
Process all pending commands, update timer, and broadcast state.
Returns true if the application should quit.
Sourcepub fn state(&self) -> &PresentationState
pub fn state(&self) -> &PresentationState
Get a reference to the current state (for engine-internal use).